==> spip_2.0.10.orig.tar.gz: spip-2.0.10.orig/ecrire/lang/public_eo.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Hejmpa&#285;o',
'articles' => 'Artikoloj',
'articles_auteur' => 'Artikoloj de tiu a&#365;toro',
'articles_populaires' => 'La plej popularaj artikoloj',
'articles_rubrique' => 'Artikoloj el tiu rubriko',
'aucun_article' => 'Neniu artikolo &#265;e tiu adreso',
'aucun_auteur' => 'Neniu a&#365;toro por tiu adreso',
'aucun_site' => 'Neniu retejo &#265;e tiu adreso',
'aucune_breve' => 'Neniu fulm-informo &#265;e tiu adreso',
'aucune_rubrique' => 'Neniu rubriko &#265;e tiu adreso',
'autres_breves' => 'Neniu fulm-informo',
'autres_groupes_mots_clefs' => 'Aliaj grupoj de &#349;losilvortoj',
'autres_sites' => 'Aliaj retejoj',

// B
'bonjour' => 'Bonan tagon',
'breves' => 'Fulm-informoj',

// C
'commenter_site' => 'Komenti tiun retejon',

// D
'date' => 'Dato',
'dernier_ajout' => 'Lasta aldono',
'dernieres_breves' => 'Lastaj fulm-informoj',
'derniers_articles' => 'Lastaj artikoloj',
'derniers_commentaires' => 'Lastaj komentoj',
'derniers_messages_forum' => 'Lastaj mesa&#285;oj publikigitaj en la forumoj',

// E
'edition_mode_texte' => 'Teksta eldono de',
'en_reponse' => 'Responde al&nbsp;:',
'en_resume' => 'Resume',
'envoyer_message' => 'Sendi mesa&#285;on',
'espace_prive' => 'Privata spaco',

// F
'forum' => 'Forumo',

// H
'hierarchie_site' => 'Hierarkio de la retejo',

// J
'jours' => 'tagoj',

// M
'meme_auteur' => 'De la sama a&#365;toro',
'meme_rubrique' => 'En la sama rubriko',
'memes_auteurs' => 'De samaj a&#365;toroj',
'message' => 'Mesa&#285;o',
'messages_forum' => 'Forum-mesa&#285;oj',
'messages_recents' => 'La plej fre&#349;aj forum-mesa&#285;oj',
'mots_clefs' => '&#348;losilvortoj',
'mots_clefs_meme_groupe' => '&#348;losilvortoj en la sama grupo',

// N
'navigation' => 'Retumado',
'nom' => 'Nomo',
'nouveautes' => 'La nova&#309;oj',
'nouveautes_web' => 'Nova&#309;oj &#265;e la reto',
'nouveaux_articles' => 'Novaj artikoloj',
'nouvelles_breves' => 'Novaj fulm-informoj',

// P
'page_precedente' => 'anta&#365;a pa&#285;o',
'page_suivante' => 'sekvanta pa&#285;o',
'par_auteur' => 'de ',
'participer_site' => 'Por partopreni la vivon de tiu retejo kaj proponi viajn propajn artikolojn, registri&#285;u &#265;i sube. Vi tuj ricevos retleteron indikante ensalutilojn por eniri la privatan spacon.',
'plan_site' => 'Mapo de la retejo',
'popularite' => 'Populareco',
'poster_message' => 'Sendi mesa&#285;on',
'proposer_site' => 'Vi povas proponi retejon aldonotan al tiu rubriko&nbsp;:',

// R
'repondre_article' => 'Respondi al tiu artikolo',
'repondre_breve' => 'Respondi al tiu fulm-informo',
'repondre_message' => 'Respondi al tiu mesa&#285;o',
'resultats_recherche' => 'Ser&#265;o-rezultoj',
'retour_debut_forums' => 'Reen al forumoj-komenco',
'rubrique' => 'Rubriko',
'rubriques' => 'Rubrikoj',

// S
'signatures_petition' => 'Subskriboj',
'site_realise_avec_spip' => 'Retejo pelata de SPIP',
'sites_web' => 'Retejoj',
'sous_rubriques' => 'Sub-rubrikoj',
'suite' => 'sekvo',
'sur_web' => '&#264;e la reto',
'syndiquer_rubrique' => 'Abonrilatigi tiun rubrikon',
'syndiquer_site' => 'Abonrilatigi la tutan retejon',

// T
'texte_lettre_information' => 'Jen la reteja inform-letero',
'texte_lettre_information_2' => 'Tiu letero enkalkulas artikolojn la kaj fulm-informojn publikigitajn de',

// V
'ver_imprimer' => 'Elprintota versio',
'voir_en_ligne' => 'Vidi konektite',
'voir_squelette' => 'vidi la skeleton de tiu pa&#285;o'
);

?>

==> spip_2.1.orig.tar.gz: spip-2.1.orig/ecrire/lang/public_eo.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Hejmpa&#285;o',
'article' => 'Article', # NEW
'articles' => 'Artikoloj',
'articles_auteur' => 'Artikoloj de tiu a&#365;toro',
'articles_populaires' => 'La plej popularaj artikoloj',
'articles_rubrique' => 'Artikoloj el tiu rubriko',
'aucun_article' => 'Neniu artikolo &#265;e tiu adreso',
'aucun_auteur' => 'Neniu a&#365;toro por tiu adreso',
'aucun_site' => 'Neniu retejo &#265;e tiu adreso',
'aucune_breve' => 'Neniu fulm-informo &#265;e tiu adreso',
'aucune_rubrique' => 'Neniu rubriko &#265;e tiu adreso',
'auteur' => 'Auteur', # NEW
'autres' => 'Aliaj',
'autres_breves' => 'Neniu fulm-informo',
'autres_groupes_mots_clefs' => 'Aliaj grupoj de &#349;losilvortoj',
'autres_sites' => 'Aliaj retejoj',

// B
'bonjour' => 'Bonan tagon',
'breve' => 'Br&egrave;ve', # NEW
'breves' => 'Fulm-informoj',

// C
'commenter_site' => 'Komenti tiun retejon',
'copie_document_impossible' => 'Estas neeble kopii la dokumenton',

// D
'date' => 'Dato',
'dernier_ajout' => 'Lasta aldono',
'dernieres_breves' => 'Lastaj fulm-informoj',
'derniers_articles' => 'Lastaj artikoloj',
'derniers_commentaires' => 'Lastaj komentoj',
'derniers_messages_forum' => 'Lastaj mesa&#285;oj publikigitaj en la forumoj',
'documents_interdits_forum' => 'Dokumentoj malpermesitaj en la forumo',

// E
'edition_mode_texte' => 'Teksta eldono de',
'en_reponse' => 'Responde al&nbsp;:',
'en_resume' => 'Resume',
'envoyer_message' => 'Sendi mesa&#285;on',
'espace_prive' => 'Privata spaco',

// F
'formats_acceptes' => 'Formatoj akceptitaj : @formats@.',
'forum' => 'Forumo',

// H
'hierarchie_site' => 'Hierarkio de la retejo',

// J
'jours' => 'tagoj',

// L
'lien_connecter' => 'Ensaluti',

// M
'meme_auteur' => 'De la sama a&#365;toro',
'meme_rubrique' => 'En la sama rubriko',
'memes_auteurs' => 'De samaj a&#365;toroj',
'message' => 'Mesa&#285;o',
'messages_forum' => 'Forum-mesa&#285;oj',
'messages_recents' => 'La plej fre&#349;aj forum-mesa&#285;oj',
'mots_clef' => 'Mot-cl&eacute;', # NEW
'mots_clefs' => '&#348;losilvortoj',
'mots_clefs_meme_groupe' => '&#348;losilvortoj en la sama grupo',

// N
'navigation' => 'Retumado',
'nom' => 'Nomo',
'nouveautes' => 'La nova&#309;oj',
'nouveautes_web' => 'Nova&#309;oj &#265;e la reto',
'nouveaux_articles' => 'Novaj artikoloj',
'nouvelles_breves' => 'Novaj fulm-informoj',

// P
'page_precedente' => 'anta&#365;a pa&#285;o',
'page_suivante' => 'sekvanta pa&#285;o',
'par_auteur' => 'de ',
'participer_site' => 'Por partopreni la vivon de tiu retejo kaj proponi viajn propajn artikolojn, registri&#285;u &#265;i sube. Vi tuj ricevos retleteron indikante ensalutilojn por eniri la privatan spacon.',
'plan_site' => 'Mapo de la retejo',
'popularite' => 'Populareco',
'poster_message' => 'Sendi mesa&#285;on',
'proposer_site' => 'Vi povas proponi retejon aldonotan al tiu rubriko&nbsp;:',

// R
'repondre_article' => 'Respondi al tiu artikolo',
'repondre_breve' => 'Respondi al tiu fulm-informo',
'repondre_message' => 'Respondi al tiu mesa&#285;o',
'resultats_recherche' => 'Ser&#265;o-rezultoj',
'retour_debut_forums' => 'Reen al forumoj-komenco',
'rubrique' => 'Rubriko',
'rubriques' => 'Rubrikoj',

// S
'signatures_petition' => 'Subskriboj',
'site_realise_avec_spip' => 'Retejo pelata de SPIP',
'sites_web' => 'Retejoj',
'sous_rubriques' => 'Sub-rubrikoj',
'spam' => 'Trudmesa&#285;o',
'suite' => 'sekvo',
'sur_web' => '&#264;e la reto',
'syndiquer_rubrique' => 'Abonrilatigi tiun rubrikon',
'syndiquer_site' => 'Abonrilatigi la tutan retejon',

// T
'texte_lettre_information' => 'Jen la reteja inform-letero',
'texte_lettre_information_2' => 'Tiu letero enkalkulas artikolojn la kaj fulm-informojn publikigitajn de',

// V
'ver_imprimer' => 'Elprintota versio',
'voir_en_ligne' => 'Vidi konektite',
'voir_squelette' => 'vidi la skeleton de tiu pa&#285;o'
);

?>
